# Introduction
Welcome to the Heterogeneous Catalysis example upload showcasing some functionalities of the [`nomad-catalysis` plugin](https://github.com/FAIRmat-NFDI/nomad-catalysis-plugin).
In this example upload you find one entry for a catalyst sample, and one for a catalytic reaction. The data for the catalytic reaction is read out from an excel sheet which you can download under the files tab. More options for properties which can be read in directly from the excel sheet can be found in the [nomad-catalysis plugin documentation](https://fairmat-nfdi.github.io/nomad-catalysis-plugin/) [here](https://fairmat-nfdi.github.io/nomad-catalysis-plugin/how_to/use_this_plugin.html#format-of-the-csv-or-xlsx-data-file).

# Viewing uploaded data

You can see a list of the included files under the `> /` button after clicking it below or after navigating to the `Files` tab on the top of the page, where you can also download single files.
To get an overview about what data is in the whole upload, click on the Search icon at the top of the page and select the `Heterogeneous Catalysis ` search page.


# Where to go from here

If you are interested in uploading your data to NOMAD and have general questions you will find support at [FAIRmat](https://www.fairmat-nfdi.eu/fairmat/). For questions related to this example or catalysis data in general contact [Julia Schumann](mailto:jschumann@physik.hu-berlin.de) or another member of the [FAIRmat team](https://www.fairmat-nfdi.eu/fairmat/about-fairmat/contact-fairmat).